@@ -492,6 +492,9 @@ static SilcSKRStatus silc_skr_add_silc_simple(SilcSKR skr,
 {
   SilcSKRKeyInternal key;
   SilcSKRStatus status = SILC_SKR_ERROR;
+#if defined(SILC_DEBUG)
+  char tmp[256];
+#endif /* SILC_DEBUG */
 
   SILC_LOG_DEBUG(("Adding SILC public key"));
 
@@ -516,6 +519,12 @@ static SilcSKRStatus silc_skr_add_silc_simple(SilcSKR skr,
   key->key.key = public_key;
   key->key.key_context = key_context;
 
+#if defined(SILC_DEBUG)
+  silc_skr_type_string(SILC_SKR_FIND_USAGE, SILC_32_TO_PTR(usage),
+		       tmp, sizeof(tmp) - 1);
+  SILC_LOG_DEBUG(("Search cons %s", tmp));
+#endif /* SILC_DEBUG */
+
   /* Add key specifics */
 
   if (!silc_skr_add_entry(skr, SILC_SKR_FIND_PUBLIC_KEY,
@@ -623,8 +632,7 @@ void silc_skr_free(SilcSKR skr)
 
 SilcBool silc_skr_init(SilcSKR skr)
 {
-  if (!silc_mutex_alloc(&skr->lock))
-    return FALSE;
+  silc_mutex_alloc(&skr->lock);
 
   skr->keys = silc_hash_table_alloc(0, silc_skr_hash, NULL,
 				    silc_skr_compare, NULL,
@@ -740,7 +748,7 @@ void silc_skr_ref_public_key(SilcSKR skr, SilcSKRKey key)
   SilcSKRKeyInternal k = (SilcSKRKeyInternal)key;
 
   silc_mutex_lock(skr->lock);
-  SILC_LOG_DEBUG(("SKR key %p ref %d -> %d", k->refcnt, k->refcnt + 1));
+  SILC_LOG_DEBUG(("SKR key %p ref %d -> %d", k, k->refcnt, k->refcnt + 1));
   k->refcnt++;
   silc_mutex_unlock(skr->lock);
 }
@@ -753,7 +761,7 @@ void silc_skr_unref_public_key(SilcSKR skr, SilcSKRKey key)
 
   silc_mutex_lock(skr->lock);
 
-  SILC_LOG_DEBUG(("SKR key %p ref %d -> %d", k->refcnt, k->refcnt - 1));
+  SILC_LOG_DEBUG(("SKR key %p ref %d -> %d", k, k->refcnt, k->refcnt - 1));
   k->refcnt--;
 
   if (k->refcnt == 0) {
