@@ -4,7 +4,7 @@
 
   Author: Pekka Riikonen <priikone@silcnet.org>
 
-  Copyright (C) 1998 - 2007 Pekka Riikonen
+  Copyright (C) 1998 - 2008 Pekka Riikonen
 
   The contents of this file are subject to one of the Licenses specified 
   in the COPYING file;  You may not use this file except in compliance 
@@ -274,7 +274,7 @@ SilcBool silc_schedule_internal_schedule_fd(SilcSchedule schedule,
   if (!internal)
     return TRUE;
 
-  SILC_LOG_DEBUG(("Scheduling fd %lu, mask %x", task->fd, event_mask));
+  SILC_LOG_DEBUG(("Scheduling fd %u, mask %x", task->fd, event_mask));
 
   memset(&event, 0, sizeof(event));
   if (event_mask & SILC_TASK_READ)
@@ -288,6 +288,7 @@ SilcBool silc_schedule_internal_schedule_fd(SilcSchedule schedule,
       SILC_LOG_DEBUG(("epoll_ctl (DEL): %s", strerror(errno)));
       return FALSE;
     }
+    task->scheduled = FALSE;
     return TRUE;
   }
 
